
__name__ = 'tinybird-cli'
__description__ = 'Tinybird Command Line Tool'
__url__ = 'https://www.tinybird.co/docs/cli/introduction.html'
__author__ = 'Tinybird'
__author_email__ = 'support@tinybird.co'
__version__ = '5.11.0'
__revision__ = '7676491'
